"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const microservice_1 = require("@jfrog-pipelines/microservice");
const utility_1 = require("@jfrog-pipelines/utility");
const data_access_layer_1 = require("@jfrog-pipelines/data-access-layer");
const NodePoolWorker_1 = require("./NodePoolWorker");
const logLevel = 'trace';
const QUEUE_NAME = 'core.nodePoolService';
const store = microservice_1.globalStore;
const serviceEnum = 14;
const serviceDetails = utility_1.ServiceMeta[serviceEnum];
const options = {
    enum: serviceEnum,
    initializers: [new microservice_1.AmqpClientInitializer()],
    healthChecks: [],
    logLevel: logLevel,
    models: [data_access_layer_1.BuildPlaneMessage, data_access_layer_1.Lock, data_access_layer_1.Node, data_access_layer_1.NodePool],
    productHome: process.env.APP_CONFIG_PATH,
    validator: new microservice_1.DefaultApplicationValidator([], [])
};
async function startApp() {
    const app = new microservice_1.Application(options, store);
    const poolWorker = new NodePoolWorker_1.NodePoolWorker(serviceDetails, store);
    await app.listen(QUEUE_NAME, poolWorker);
    await poolWorker.startCollectingOrphanNodes();
}
startApp();
//# sourceMappingURL=app.js.map