import { Node, NodePool } from '@jfrog-pipelines/data-access-layer';
import { AmqpPublisher } from '@jfrog-pipelines/amqp-client';
import { AccessClient } from '@jfrog/access-nodejs-client';
import { ConfigurationProperties } from '@jfrog-pipelines/configuration';
import { UnknownType } from '@jfrog-pipelines/types';
import { NodeDao } from './NodeDao';
export declare enum NodeStatus {
    queued = 4000,
    processing = 4001,
    success = 4002,
    failure = 4003,
    waiting = 4005,
    cancelled = 4006,
    unstable = 4007,
    skipped = 4008,
    timeout = 4009,
    stopped = 4010,
    deleted = 4011,
    cached = 4012,
    cancelling = 4013,
    timingout = 4014
}
export declare const ActiveNodeStatus: NodeStatus[];
export declare const NodeAccessorID = "1";
export declare enum NodeActions {
    CREATE = 10,
    CACHE = 20,
    START = 30,
    DELETE = 40
}
export declare type NodeCreateAttributes = {
    projectId: number;
    nodePoolId: number;
    friendlyName: string;
    isOnDemand: boolean;
    statusCode: number;
    statusLastUpdatedAt: Date;
    createdBy?: string;
    updatedBy?: string;
    stopRequested: boolean;
    intendedBuildPlaneVersion: string;
    projectIntegrationId: number;
    sshPort: number;
    sshUser: string;
    systemPropertyBag: UnknownType;
    initPropertyBag: UnknownType;
    isAutoInitialized: boolean;
};
export declare class NodeService {
    private readonly publisher;
    private readonly logger;
    nodeDao: NodeDao;
    accessClient: AccessClient;
    properties: ConfigurationProperties;
    constructor(publisher: AmqpPublisher);
    release(): Promise<void>;
    createNode(attribute: NodeCreateAttributes): Promise<Node>;
    getRunningNodes(poolID: number): Promise<Node[]>;
    getAllNodes(poolID: number): Promise<Node[]>;
    getOrphanNodes(): Promise<Node[]>;
    filterActiveNodes(nodes: Node[]): Node[];
    filterIdleNodes(nodePool: NodePool, nodes: Node[]): Node[];
    filterCachedNodes(nodes: Node[]): Node[];
    applyNodeToStoppedState(node: Node): Promise<Node>;
    applyNodeToCachedState(node: Node): Promise<Node>;
    applyNodeWaitingState(node: Node): Promise<Node>;
    private applyNodeState;
    private getNodeAccessToken;
    private updateNodeBootStrapToken;
    private sendWWWSignal;
}
